@@ -85,8 +85,7 @@ class Daily():
         if rso_type is None:
             pass
         elif rso_type.lower() not in ['simple', 'full', 'array']:
-            raise ValueError(
-                'rso_type must be None, "simple", "full", or "array')
+            raise ValueError('rso_type must be None, "simple", "full", or "array')
         elif rso_type.lower() in 'array':
             # Check that rso is an ee.Image or ee.Number?
             pass
@@ -120,8 +119,8 @@ class Daily():
         self.es_slope = calcs._es_slope(self.tmean, method)
 
         # Saturated vapor pressure
-        self.es = calcs._sat_vapor_pressure(self.tmax).add(
-            calcs._sat_vapor_pressure(self.tmin)) \
+        self.es = calcs._sat_vapor_pressure(self.tmax)\
+            .add(calcs._sat_vapor_pressure(self.tmin))\
             .multiply(0.5)
 
         # Vapor pressure deficit
@@ -138,14 +137,14 @@ class Daily():
                 self.rso = calcs._rso_simple(ra=self.ra, elev=self.elev)
             elif method.lower() == 'refet':
                 self.rso = calcs._rso_daily(
-                    ea=self.ea, ra=self.ra, pair=self.pair, doy=self.doy,
-                    lat=self.lat)
+                    ea=self.ea, ra=self.ra, pair=self.pair, doy=self.doy, lat=self.lat
+                )
         elif rso_type.lower() == 'simple':
             self.rso = calcs._rso_simple(ra=self.ra, elev=self.elev)
         elif rso_type.lower() == 'full':
             self.rso = calcs._rso_daily(
-                ea=self.ea, ra=self.ra, pair=self.pair, doy=self.doy,
-                lat=self.lat)
+                ea=self.ea, ra=self.ra, pair=self.pair, doy=self.doy, lat=self.lat
+            )
         elif rso_type.lower() == 'array':
             # Use rso array passed to function
             self.rso = rso
@@ -248,7 +247,6 @@ class Daily():
         #     .rename(['etw'])\
         #     .set('system:time_start', self.time_start)
 
-
     @lazy_property
     def eto_fs1(self):
         """UF-IFAS Extension FS1 Radiation Term (ETrad)
@@ -263,9 +261,11 @@ class Daily():
         https://edis.ifas.ufl.edu/pdffiles/ae/ae45900.pdf
 
         """
-        return self.u2.expression(
-            '(delta / (delta + psy*(1+0.34*u2)))*(0.408*rn)',
-            {'delta': self.es_slope, 'psy': self.psy, 'u2': self.u2, 'rn': self.rn})\
+        return self.u2\
+            .expression(
+                '(delta / (delta + psy * (1 + 0.34 * u2))) * (0.408 * rn)',
+                {'delta': self.es_slope, 'psy': self.psy, 'u2': self.u2,
+                 'rn': self.rn})\
             .rename(['eto_fs1'])\
             .set('system:time_start', self.time_start)
 
@@ -273,8 +273,6 @@ class Daily():
         #       .divide(self.es_slope.add(self.psy.multiply(self.u2.multiply(0.34).add(1))))\
         #       .multiply(self.rn.multiply(0.408))
 
-
-
     @lazy_property
     def eto_fs2(self):
         """UF-IFAS Extension FS2 Wind Term (ETwind)
@@ -290,14 +288,18 @@ class Daily():
 
         """
         # Temperature Term (Eq. 14)
-        self.TT = self.u2.expression('(900/(t+273))*u2', {'t': self.tmean, 'u2': self.u2})
+        TT = self.u2.expression(
+            '(900 / (t + 273)) * u2',
+            {'t': self.tmean, 'u2': self.u2})
         # Psi Term (Eq. 13)
-        self.PT = self.u2.expression('psy/(slope+psy*(1+0.34*u2))', {'slope': self.es_slope, 'psy': self.psy,
-                                                                     'u2': self.u2})
+        PT = self.u2.expression(
+            'psy / (slope + psy * (1 + 0.34 * u2))',
+            {'slope': self.es_slope, 'psy': self.psy, 'u2': self.u2})
 
-        return self.u2.expression(
-            'PT * TT * (es-ea)',
-            {'PT': self.PT, 'TT': self.TT, 'es': self.es, 'ea': self.ea})\
+        return self.u2\
+            .expression(
+                'PT * TT * (es-ea)',
+                {'PT': PT, 'TT': TT, 'es': self.es, 'ea': self.ea})\
             .rename(['eto_fs2'])\
             .set('system:time_start', self.time_start)
 
@@ -306,6 +308,32 @@ class Daily():
         #     .rename(['eto_fs2'])\
         #     .set('system:time_start', self.time_start)
 
+    @lazy_property
+    def pet_hargreaves(self):
+        """Hargreaves potential ET
+
+        Returns
+        -------
+        hargreaves_pet : ee.Image
+            Hargreaves ET [mm].
+
+        References
+        ----------
+
+        """
+        return self.tmax\
+            .expression(
+                '0.0023 * (tmean + 17.8) * ((tmax - tmin) ** 0.5) * 0.408 * ra',
+                {'tmean': self.tmean, 'tmax': self.tmax, 'tmin': self.tmin,
+                 'ra': self.ra})\
+            .rename(['pet_hargreaves'])\
+            .set('system:time_start', self.time_start)
+        # return self.ra\
+        #     .multiply(self.tmean.add(17.8))\
+        #     .multiply(self.tmax.subtract(self.tmin).pow(0.5))\
+        #     .multiply(0.0023 * 0.408)\
+        #     .rename(['pet_hargreaves'])\
+        #     .set('system:time_start', self.time_start)
 
     @classmethod
     def gridmet(cls, input_img, zw=None, elev=None, lat=None, method='asce',
@@ -506,16 +534,15 @@ class Daily():
         if zw is None:
             zw = ee.Number(10)
         if elev is None:
-            elev = ee.Image('projects/earthengine-legacy/assets/'
-                            'projects/eddi-noaa/nldas/elevation')\
-                .rename(['elevation'])
+            elev = ee.Image('projects/openet/assets/meteorology/nldas/ancillary/elevation')
             # elev = ee.Image('CGIAR/SRTM90_V4')\
             #     .reproject('EPSG:4326', [0.125, 0, -125, 0, -0.125, 53])
         if lat is None:
-            lat = ee.Image('projects/earthengine-legacy/assets/'
-                           'projects/eddi-noaa/nldas/elevation')\
-                .multiply(0).add(ee.Image.pixelLonLat().select('latitude'))\
-                .rename(['latitude'])
+            lat = ee.Image('projects/openet/assets/meteorology/nldas/ancillary/latitude')
+            # lat = ee.Image('projects/earthengine-legacy/assets/'
+            #                'projects/eddi-noaa/nldas/elevation')\
+            #     .multiply(0).add(ee.Image.pixelLonLat().select('latitude'))\
+            #     .rename(['latitude'])
             # lat = ee.Image.pixelLonLat().select('latitude')\
             #     .reproject('EPSG:4326', [0.125, 0, -125, 0, -0.125, 53])
             # lat = input_coll.first().select([0]).multiply(0)\
@@ -526,12 +553,12 @@ class Daily():
             return ee.Image(input_img.select(['wind_u'])).pow(2)\
                 .add(ee.Image(input_img.select(['wind_v'])).pow(2))\
                 .sqrt().rename(['uz'])
-        wind_img = ee.Image(
-            ee.ImageCollection(input_coll.map(wind_magnitude)).mean())
+        wind_img = ee.Image(ee.ImageCollection(input_coll.map(wind_magnitude)).mean())
 
         ea_img = calcs._actual_vapor_pressure(
             pair=calcs._air_pressure(elev, method),
-            q=input_coll.select(['specific_humidity']).mean())
+            q=input_coll.select(['specific_humidity']).mean()
+        )
 
         return cls(
             tmax=input_coll.select(['temperature']).max(),
@@ -549,7 +576,7 @@ class Daily():
 
     @classmethod
     def cfsv2(cls, input_coll, zw=None, elev=None, lat=None, method='asce',
-             rso_type=None):
+              rso_type=None):
         """Initialize daily RefET from a 6-hourly CFSv2 image collection
 
         Parameters
@@ -611,8 +638,7 @@ class Daily():
             u_img = ee.Image(input_img).select(['u-component_of_wind_height_above_ground'])
             v_img = ee.Image(input_img).select(['v-component_of_wind_height_above_ground'])
             return u_img.pow(2).add(v_img.pow(2)).sqrt()
-        wind_img = ee.Image(
-            ee.ImageCollection(input_coll.map(wind_magnitude)).mean())
+        wind_img = ee.Image(ee.ImageCollection(input_coll.map(wind_magnitude)).mean())
 
         ea_img = calcs._actual_vapor_pressure(
             pair=calcs._air_pressure(elev, method),
@@ -743,3 +769,197 @@ class Daily():
             method=method,
             rso_type=rso_type,
         )
+
+    @classmethod
+    def era5(cls, input_coll, zw=None, elev=None, lat=None, method='asce',
+             rso_type=None):
+        """Initialize daily RefET from an hourly ERA5 image collection
+
+        Parameters
+        ----------
+        input_coll : ee.ImageCollection
+            Collection of ERA5 hourly images for a single day from the
+            collection ECMWF/ERA5/HOURLY.
+        zw : ee.Number, optional
+            Wind speed height [m] (the default is 10).
+        elev : ee.Image or ee.Number, optional
+            Elevation image [m].  The OpenET ERA5 elevation image
+            (projects/openet/assets/meteorology/era5/ancillary/elevation)
+            will be used if not set.
+        lat : ee.Image or ee.Number
+            Latitude image [degrees].  The OpenET ERA5 latitude image
+            (projects/openet/assets/meteorology/era5/ancillary/latitude)
+            will be used if not set.
+        method : {'asce' (default), 'refet'}, optional
+            Specifies which calculation method to use.
+            * 'asce' -- Calculations will follow ASCE-EWRI 2005.
+            * 'refet' -- Calculations will follow RefET software.
+        rso_type : {None (default), 'full' , 'simple'}, optional
+            Specifies which clear sky solar radiation (Rso) model to use.
+            * None -- Rso type will be determined from "method" parameter
+            * 'full' -- Full clear sky solar formulation
+            * 'simple' -- Simplified clear sky solar formulation
+
+        Notes
+        -----
+        Temperatures are converted from K to C.
+        Solar radiation is summed and converted from J m-2 to MJ m-2 day-1.
+        Actual vapor pressure is computed from dew point temperature.
+
+        """
+        input_coll = ee.ImageCollection(input_coll)
+        start_date = ee.Date(ee.Image(input_coll.first()).get('system:time_start'))
+
+        if zw is None:
+            zw = ee.Number(10)
+        if elev is None:
+            elev = ee.Image('projects/openet/assets/meteorology/era5/ancillary/elevation')
+        if lat is None:
+            lat = ee.Image('projects/openet/assets/meteorology/era5/ancillary/latitude')\
+            # lat = ee.Image('projects/openet/assets/meteorology/era5/ancillary/elevation')\
+            #     .multiply(0).add(ee.Image.pixelLonLat().select('latitude'))\
+            #     .rename(['latitude'])
+
+        def wind_magnitude(input_img):
+            """Compute hourly wind magnitude from vectors"""
+            return ee.Image(input_img.select(['u_component_of_wind_10m'])).pow(2)\
+                .add(ee.Image(input_img.select(['v_component_of_wind_10m'])).pow(2))\
+                .sqrt().rename(['wind_10m'])
+
+        wind_img = ee.Image(ee.ImageCollection(input_coll.map(wind_magnitude)).mean())
+
+        return cls(
+            tmax=input_coll.select(['temperature_2m']).max().subtract(273.15),
+            tmin=input_coll.select(['temperature_2m']).min().subtract(273.15),
+            ea=calcs._sat_vapor_pressure(
+                input_coll.select(['dewpoint_temperature_2m']).mean().subtract(273.15)
+            ),
+            rs=input_coll.select(['surface_solar_radiation_downwards'])
+                .sum().divide(1000000),
+            uz=wind_img,
+            zw=zw,
+            elev=elev,
+            lat=lat,
+            doy=ee.Number(start_date.getRelative('day', 'year')).add(1).double(),
+            method=method,
+            rso_type=rso_type,
+        )
+
+    @classmethod
+    def era5_land(cls, input_coll, zw=None, elev=None, lat=None,
+                  method='asce', rso_type=None):
+        """Initialize daily RefET from an hourly ERA5-Land image collection
+
+        Parameters
+        ----------
+        input_coll : ee.ImageCollection
+            Collection of ERA5-Land hourly images for a single day from the
+            collection ECMWF/ERA5_LAND/HOURLY.
+        zw : ee.Number, optional
+            Wind speed height [m] (the default is 10).
+        elev : ee.Image or ee.Number, optional
+            Elevation image [m].  The OpenET ERA5-Land elevation image
+            (projects/openet/assets/meteorology/era5land/ancillary/elevation)
+            will be used if not set.
+        lat : ee.Image or ee.Number
+            Latitude image [degrees].  The OpenET ERA5-Land latitude image
+            (projects/openet/assets/meteorology/era5land/ancillary/latitude)
+            will be used if not set.
+        method : {'asce' (default), 'refet'}, optional
+            Specifies which calculation method to use.
+            * 'asce' -- Calculations will follow ASCE-EWRI 2005.
+            * 'refet' -- Calculations will follow RefET software.
+        rso_type : {None (default), 'full' , 'simple'}, optional
+            Specifies which clear sky solar radiation (Rso) model to use.
+            * None -- Rso type will be determined from "method" parameter
+            * 'full' -- Full clear sky solar formulation
+            * 'simple' -- Simplified clear sky solar formulation
+
+        Notes
+        -----
+        Temperatures are converted from K to C.
+        Solar radiation is summed and converted from J m-2 to MJ m-2 day-1.
+        Actual vapor pressure is computed from dew point temperature.
+
+        """
+        input_coll = ee.ImageCollection(input_coll)
+        start_date = ee.Date(ee.Image(input_coll.first()).get('system:time_start'))
+
+        if zw is None:
+            zw = ee.Number(10)
+        if elev is None:
+            elev = ee.Image('projects/openet/assets/meteorology/era5land/ancillary/elevation')
+        if lat is None:
+            lat = ee.Image('projects/openet/assets/meteorology/era5land/ancillary/latitude')\
+            # lat = ee.Image('projects/openet/assets/meteorology/era5land/ancillary/elevation')\
+            #     .multiply(0).add(ee.Image.pixelLonLat().select('latitude'))\
+            #     .rename(['latitude'])
+
+        def wind_magnitude(input_img):
+            """Compute hourly wind magnitude from vectors"""
+            return ee.Image(input_img.select(['u_component_of_wind_10m'])).pow(2)\
+                .add(ee.Image(input_img.select(['v_component_of_wind_10m'])).pow(2))\
+                .sqrt().rename(['wind_10m'])
+
+        wind_img = ee.Image(ee.ImageCollection(input_coll.map(wind_magnitude)).mean())
+
+        return cls(
+            tmax=input_coll.select(['temperature_2m']).max().subtract(273.15),
+            tmin=input_coll.select(['temperature_2m']).min().subtract(273.15),
+            ea=calcs._sat_vapor_pressure(
+                input_coll.select(['dewpoint_temperature_2m']).mean().subtract(273.15)
+            ),
+            rs=input_coll.select(['surface_solar_radiation_downwards_hourly'])
+                .sum().divide(1000000),
+            uz=wind_img,
+            zw=zw,
+            elev=elev,
+            lat=lat,
+            doy=ee.Number(start_date.getRelative('day', 'year')).add(1).double(),
+            method=method,
+            rso_type=rso_type,
+        )
+
+    # @classmethod
+    # def prism(cls, input_img, lat=None):
+    #     """Initialize daily RefET from a PRISM image
+    #
+    #     Parameters
+    #     ----------
+    #     input_img : ee.Image
+    #         PPRISM image from the collection OREGONSTATE/PRISM/AN81d.
+    #     lat : ee.Image or ee.Number
+    #         Latitude image [degrees].  The latitude will be computed
+    #         dynamically using ee.Image.pixelLonLat() if not set.
+    #
+    #     Notes
+    #     -----
+    #     PRISM can only be used to compute Hargreaves PET.
+    #
+    #     """
+    #     image_date = ee.Date(input_img.get('system:time_start'))
+    #
+    #     if lat is None:
+    #         lat = ee.Image('projects/earthengine-legacy/assets/'
+    #                        'projects/climate-engine/prism/elevation')\
+    #             .multiply(0).add(ee.Image.pixelLonLat().select('latitude'))\
+    #             .rename(['latitude'])
+    #         # prism_transform = [0.0416666666667, 0, -125.02083333333336,
+    #         #                    0, -0.0416666666667, 49.93749999999975]
+    #         # lat = ee.Image.pixelLonLat().select('latitude')\
+    #         #     .reproject('EPSG:4326', prism_transform)
+    #         # lat = input_img.select([0]).multiply(0)\
+    #         #     .add(ee.Image.pixelLonLat().select('latitude'))
+    #
+    #     return cls(
+    #         tmax=input_img.select(['tmmx']),
+    #         tmin=input_img.select(['tmmn']),
+    #         ea=0,
+    #         rs=0,
+    #         uz=0,
+    #         zw=2,
+    #         elev=0,
+    #         lat=lat,
+    #         doy=ee.Number(image_date.getRelative('day', 'year')).add(1).double(),
+    #         method='asce',
+    #     )
