@@ -113,8 +113,8 @@ class Hourly():
         # Extraterrestrial radiation
         time_mid = self.time.add(0.5)
         self.ra = calcs._ra_hourly(
-            lat=self.lat, lon=self.lon, doy=self.doy, time_mid=time_mid,
-            method=method)
+            lat=self.lat, lon=self.lon, doy=self.doy, time_mid=time_mid, method=method
+        )
 
         # Clear sky solar radiation
         if method == 'asce':
@@ -122,7 +122,8 @@ class Hourly():
         elif method == 'refet':
             self.rso = calcs._rso_hourly(
                 ea=self.ea, ra=self.ra, pair=self.pair, doy=self.doy,
-                time_mid=time_mid, lat=self.lat, lon=self.lon, method=method)
+                time_mid=time_mid, lat=self.lat, lon=self.lon, method=method
+            )
 
         # Cloudiness fraction
         # Intentionally not using time_mid to match Beta value in IN2 file
@@ -131,7 +132,8 @@ class Hourly():
         # Beta (not SinBeta) is used for clamping fcd.
         self.fcd = calcs._fcd_hourly(
             rs=self.rs, rso=self.rso, doy=self.doy, time_mid=self.time,
-            lat=self.lat, lon=self.lon, method=method)
+            lat=self.lat, lon=self.lon, method=method
+        )
 
         # Net long-wave radiation
         self.rnl = calcs._rnl_hourly(tmean=self.tmean, ea=self.ea, fcd=self.fcd)
@@ -228,7 +230,8 @@ class Hourly():
             '(es_slope + psy * (cd * u2 + 1))',
             {'cd': self.cd, 'cn': self.cn, 'es_slope': self.es_slope,
              'g': self.g, 'psy': self.psy, 'rn': self.rn, 'tmean': self.tmean,
-             'u2': self.u2, 'vpd': self.vpd})
+             'u2': self.u2, 'vpd': self.vpd}
+        )
 
     @classmethod
     def nldas(cls, input_img, zw=None, elev=None, lat=None, lon=None,
@@ -242,14 +245,17 @@ class Hourly():
         zw : ee.Number, optional
             Wind speed height [m] (the default is 10).
         elev : ee.Image or ee.Number, optional
-            Elevation image [m].  A custom NLDAS elevation image
-            (projects/eddi-noaa/nldas/elevation) will be used if not set.
+            Elevation image [m].  A precomputed NLDAS elevation image
+            (projects/openet/assets/meteorology/nldas/ancillary/elevation)
+            will be used if not set.
         lat : ee.Image or ee.Number
-            Latitude image [degrees].  The latitude will be computed
-            dynamically using ee.Image.pixelLonLat() if not set.
+            Latitude image [degrees].  A precomputed NLDAS latitude image
+            (projects/openet/assets/meteorology/nldas/ancillary/latitude)
+            will be used if not set.
         lon : ee.Image or ee.Number
-            Longitude image [degrees].  The longitude will be computed
-            dynamically using ee.Image.pixelLonLat() if not set.
+            Longitude image [degrees].  A precomputed NLDAS longitude image
+            (projects/openet/assets/meteorology/nldas/ancillary/longitude)
+            will be used if not set.
         method : {'asce' (default), 'refet'}, optional
             Specifies which calculation method to use.
             * 'asce' -- Calculations will follow ASCE-EWRI 2005.
@@ -267,25 +273,23 @@ class Hourly():
         if zw is None:
             zw = ee.Number(10)
         if elev is None:
-            elev = ee.Image('projects/earthengine-legacy/assets/'
-                            'projects/eddi-noaa/nldas/elevation')\
-                .rename(['elevation'])
+            elev = ee.Image('projects/openet/assets/meteorology/nldas/ancillary/elevation')
             # elev = ee.Image('CGIAR/SRTM90_V4')\
             #     .reproject('EPSG:4326', [0.125, 0, -125, 0, -0.125, 53])
         if lat is None:
-            lat = ee.Image('projects/earthengine-legacy/assets/'
-                           'projects/eddi-noaa/nldas/elevation')\
-                .multiply(0).add(ee.Image.pixelLonLat().select('latitude'))\
-                .rename(['latitude'])
+            lat = ee.Image('projects/openet/assets/meteorology/nldas/ancillary/latitude')
+            # lat = ee.Image('projects/openet/assets/meteorology/nldas/ancillary/elevation')\
+            #     .multiply(0).add(ee.Image.pixelLonLat().select('latitude'))\
+            #     .rename(['latitude'])
             # lat = ee.Image.pixelLonLat().select('latitude')\
             #     .reproject('EPSG:4326', [0.125, 0, -125, 0, -0.125, 53])
             # lat = nldas_img.select([0]).multiply(0)\
             #     .add(ee.Image.pixelLonLat().select('latitude'))
         if lon is None:
-            lon = ee.Image('projects/earthengine-legacy/assets/'
-                           'projects/eddi-noaa/nldas/elevation')\
-                .multiply(0).add(ee.Image.pixelLonLat().select('longitude'))\
-                .rename(['longitude'])
+            lon = ee.Image('projects/openet/assets/meteorology/nldas/ancillary/longitude')
+            # lon = ee.Image('projects/openet/assets/meteorology/nldas/ancillary/elevation')\
+            #     .multiply(0).add(ee.Image.pixelLonLat().select('longitude'))\
+            #     .rename(['longitude'])
             # lon = ee.Image.pixelLonLat().select('longitude')\
             #     .reproject('EPSG:4326', [0.125, 0, -125, 0, -0.125, 53])
             # lon = nldas_img.select([0]).multiply(0)\
@@ -297,8 +301,8 @@ class Hourly():
                 q=input_img.select(['specific_humidity']),
                 pair=calcs._air_pressure(elev, method)),
             rs=input_img.select(['shortwave_radiation']).multiply(0.0036),
-            uz=input_img.select(['wind_u']).pow(2)\
-                .add(input_img.select(['wind_v']).pow(2))\
+            uz=input_img.select(['wind_u']).pow(2)
+                .add(input_img.select(['wind_v']).pow(2))
                 .sqrt().rename(['uz']),
             zw=zw,
             elev=elev,
@@ -396,4 +400,147 @@ class Hourly():
             # time=ee.Number(start_date.getRelative('hour', 'day')),
             time=ee.Number(start_date.get('hour')),
             method=method,
-        )
\ No newline at end of file
+        )
+
+    @classmethod
+    def era5(cls, input_img, zw=None, elev=None, lat=None, lon=None, method='asce'):
+        """Initialize hourly RefET from an ERA5 image
+
+        Parameters
+        ----------
+        input_img : ee.Image
+            ERA5 hourly image from the collection ECMWF/ERA5/HOURLY.
+        zw : ee.Number, optional
+            Wind speed height [m] (the default is 10).
+        elev : ee.Image or ee.Number, optional
+            Elevation image [m].  The OpenET ERA5-Land elevation image
+            (projects/openet/assets/meteorology/era5/ancillary/elevation)
+            will be used if not set.
+        lat : ee.Image or ee.Number
+            Latitude image [degrees].  The OpenET ERA5 latitude image
+            (projects/openet/assets/meteorology/era5/ancillary/latitude)
+            will be used if not set.
+        lon : ee.Image or ee.Number
+            Longitude image [degrees].  The OpenET ERA5 longitude image
+            (projects/openet/assets/meteorology/era5/ancillary/longitude)
+            will be used if not set.
+        method : {'asce' (default), 'refet'}, optional
+            Specifies which calculation method to use.
+            * 'asce' -- Calculations will follow ASCE-EWRI 2005.
+            * 'refet' -- Calculations will follow RefET software.
+
+        Notes
+        -----
+        Temperatures are converted from K to C.
+        Solar radiation is summed and converted from J m-2 to MJ m-2 hr-1.
+        Actual vapor pressure is computed from dew point temperature.
+
+        """
+        start_date = ee.Date(input_img.get('system:time_start'))
+
+        if zw is None:
+            zw = ee.Number(10)
+        if elev is None:
+            elev = ee.Image('projects/openet/assets/meteorology/era5/ancillary/elevation')
+        if lat is None:
+            lat = ee.Image('projects/openet/assets/meteorology/era5/ancillary/latitude')
+            # lat = ee.Image('projects/openet/assets/meteorology/era5/ancillary/elevation')\
+            #     .multiply(0).add(ee.Image.pixelLonLat().select('latitude'))\
+            #     .rename(['latitude'])
+        if lon is None:
+            lon = ee.Image('projects/openet/assets/meteorology/era5/ancillary/longitude')
+            # lon = ee.Image('projects/openet/assets/meteorology/era5/ancillary/elevation')\
+            #     .multiply(0).add(ee.Image.pixelLonLat().select('longitude'))\
+            #     .rename(['longitude'])
+
+        return cls(
+            tmean=input_img.select(['temperature_2m']).subtract(273.15),
+            ea=calcs._sat_vapor_pressure(
+                input_img.select(['dewpoint_temperature_2m']).subtract(273.15)
+            ),
+            rs=input_img.select(['surface_solar_radiation_downwards'])
+                .divide(1000000),
+            uz=input_img.select(['u_component_of_wind_10m']).pow(2)
+                .add(input_img.select(['v_component_of_wind_10m']).pow(2))
+                .sqrt().rename(['wind_10m']),
+            zw=zw,
+            elev=elev,
+            lat=lat,
+            lon=lon,
+            doy=ee.Number(start_date.getRelative('day', 'year')).add(1).double(),
+            # time=ee.Number(start_date.getRelative('hour', 'day')),
+            time=ee.Number(start_date.get('hour')),
+            method=method,
+        )
+
+    @classmethod
+    def era5_land(cls, input_img, zw=None, elev=None, lat=None, lon=None,
+                  method='asce'):
+        """Initialize hourly RefET from an ERA5-Land image
+
+        Parameters
+        ----------
+        input_img : ee.Image
+            ERA5-Land hourly image from the collection ECMWF/ERA5_LAND/HOURLY.
+        zw : ee.Number, optional
+            Wind speed height [m] (the default is 10).
+        elev : ee.Image or ee.Number, optional
+            Elevation image [m].  The OpenET ERA5-Land elevation image
+            (projects/openet/assets/meteorology/era5land/ancillary/elevation)
+            will be used if not set.
+        lat : ee.Image or ee.Number
+            Latitude image [degrees].  The OpenET ERA5-Land latitude image
+            (projects/openet/assets/meteorology/era5land/ancillary/latitude)
+            will be used if not set.
+        lon : ee.Image or ee.Number
+            Longitude image [degrees].  The OpenET ERA5-Land longitude image
+            (projects/openet/assets/meteorology/era5land/ancillary/longitude)
+            will be used if not set.
+        method : {'asce' (default), 'refet'}, optional
+            Specifies which calculation method to use.
+            * 'asce' -- Calculations will follow ASCE-EWRI 2005.
+            * 'refet' -- Calculations will follow RefET software.
+
+        Notes
+        -----
+        Temperatures are converted from K to C.
+        Solar radiation is summed and converted from J m-2 to MJ m-2 hr-1.
+        Actual vapor pressure is computed from dew point temperature.
+
+        """
+        start_date = ee.Date(input_img.get('system:time_start'))
+
+        if zw is None:
+            zw = ee.Number(10)
+        if elev is None:
+            elev = ee.Image('projects/openet/assets/meteorology/era5land/ancillary/elevation')
+        if lat is None:
+            lat = ee.Image('projects/openet/assets/meteorology/era5land/ancillary/latitude')
+            # lat = ee.Image('projects/openet/assets/meteorology/era5land/ancillary/elevation')\
+            #     .multiply(0).add(ee.Image.pixelLonLat().select('latitude'))\
+            #     .rename(['latitude'])
+        if lon is None:
+            lon = ee.Image('projects/openet/assets/meteorology/era5land/ancillary/longitude')
+            # lon = ee.Image('projects/openet/assets/meteorology/era5land/ancillary/elevation')\
+            #     .multiply(0).add(ee.Image.pixelLonLat().select('longitude'))\
+            #     .rename(['longitude'])
+
+        return cls(
+            tmean=input_img.select(['temperature_2m']).subtract(273.15),
+            ea=calcs._sat_vapor_pressure(
+                input_img.select(['dewpoint_temperature_2m']).subtract(273.15)
+            ),
+            rs=input_img.select(['surface_solar_radiation_downwards_hourly'])
+                .divide(1000000),
+            uz=input_img.select(['u_component_of_wind_10m']).pow(2)
+                .add(input_img.select(['v_component_of_wind_10m']).pow(2))
+                .sqrt().rename(['wind_10m']),
+            zw=zw,
+            elev=elev,
+            lat=lat,
+            lon=lon,
+            doy=ee.Number(start_date.getRelative('day', 'year')).add(1).double(),
+            # time=ee.Number(start_date.getRelative('hour', 'day')),
+            time=ee.Number(start_date.get('hour')),
+            method=method,
+        )
