@@ -30,6 +30,7 @@ d_args = {
     'etr_rso_simple': 10.628137858930051,
     'q': 0.008691370735727117,          # Computed from Ea from Tdew
     'q_asce': 0.008692530868140688,     # Computed from Ea from Tdew
+    'pet_hargreaves': 8.247962376780558,
     'rs': 674.07 * 0.041868,            # Conversion from Langleys to MJ m-2
     'rso': 31.565939444861765,
     'tdew': units._f2c(49.84),
@@ -40,6 +41,12 @@ d_args = {
     'u2': 1.976111757722194,
 }
 
+# Compute wind x and y components
+d_args['uz_x'] = d_args['uz'] / (2 ** 0.5)
+d_args['uz_y'] = d_args['uz'] / (2 ** 0.5)
+# d_args['uz_x'] = d_args['uz']
+# d_args['uz_y'] = 0.0
+
 constant_geom = ee.Geometry.Rectangle([0, 0, 10, 10], 'EPSG:32613', False)
 
 
@@ -50,7 +57,8 @@ constant_geom = ee.Geometry.Rectangle([0, 0, 10, 10], 'EPSG:32613', False)
 #         ee.Image.constant(d_args['ea']), ee.Image.constant(d_args['rs']),
 #         ee.Image.constant(d_args['uz']), ee.Number(s_args['zw']),
 #         ee.Number(s_args['elev']), ee.Number(s_args['lat']),
-#         ee.Number(d_args['doy']), method='refet')
+#         ee.Number(d_args['doy']), method='refet',
+#     )
 #     output = refet.etr\
 #         .reduceRegion(ee.Reducer.first(), geometry=constant_geom, scale=1)\
 #         .getInfo()
@@ -61,105 +69,130 @@ constant_geom = ee.Geometry.Rectangle([0, 0, 10, 10], 'EPSG:32613', False)
 # Test surface, rso_type, and rso inputs
 def test_refet_daily_etr():
     refet = Daily(
-        tmax=ee.Image.constant(d_args['tmax']),
-        tmin=ee.Image.constant(d_args['tmin']),
-        ea=ee.Image.constant(d_args['ea']),
-        rs=ee.Image.constant(d_args['rs']),
+        tmax=ee.Image.constant(d_args['tmax']), tmin=ee.Image.constant(d_args['tmin']),
+        ea=ee.Image.constant(d_args['ea']), rs=ee.Image.constant(d_args['rs']),
         uz=ee.Image.constant(d_args['uz']), zw=ee.Number(s_args['zw']),
         elev=ee.Number(s_args['elev']), lat=ee.Number(s_args['lat']),
-        doy=ee.Number(d_args['doy']), method='refet')
+        doy=ee.Number(d_args['doy']), method='refet',
+    )
+
     output = refet.etr\
         .reduceRegion(ee.Reducer.first(), geometry=constant_geom, scale=1)\
         .getInfo()
+
     assert float(output['etr']) == pytest.approx(d_args['etr_refet'])
 
 
 def test_refet_daily_eto():
     refet = Daily(
-        tmax=ee.Image.constant(d_args['tmax']),
-        tmin=ee.Image.constant(d_args['tmin']),
-        ea=ee.Image.constant(d_args['ea']),
-        rs=ee.Image.constant(d_args['rs']),
+        tmax=ee.Image.constant(d_args['tmax']), tmin=ee.Image.constant(d_args['tmin']),
+        ea=ee.Image.constant(d_args['ea']), rs=ee.Image.constant(d_args['rs']),
         uz=ee.Image.constant(d_args['uz']), zw=ee.Number(s_args['zw']),
         elev=ee.Number(s_args['elev']), lat=ee.Number(s_args['lat']),
-        doy=ee.Number(d_args['doy']), method='refet')
+        doy=ee.Number(d_args['doy']), method='refet',
+    )
+
     output = refet.eto\
         .reduceRegion(ee.Reducer.first(), geometry=constant_geom, scale=1)\
         .getInfo()
+
     assert float(output['eto']) == pytest.approx(d_args['eto_refet'])
 
 
 def test_refet_daily_etw():
     refet = Daily(
-        tmax=ee.Image.constant(d_args['tmax']),
-        tmin=ee.Image.constant(d_args['tmin']),
-        ea=ee.Image.constant(d_args['ea']),
-        rs=ee.Image.constant(d_args['rs']),
+        tmax=ee.Image.constant(d_args['tmax']), tmin=ee.Image.constant(d_args['tmin']),
+        ea=ee.Image.constant(d_args['ea']), rs=ee.Image.constant(d_args['rs']),
         uz=ee.Image.constant(d_args['uz']), zw=ee.Number(s_args['zw']),
         elev=ee.Number(s_args['elev']), lat=ee.Number(s_args['lat']),
-        doy=ee.Number(d_args['doy']), method='refet')
+        doy=ee.Number(d_args['doy']), method='refet',
+    )
+
     output = refet.etw\
         .reduceRegion(ee.Reducer.first(), geometry=constant_geom, scale=1)\
         .getInfo()
+
     assert float(output['etw']) == pytest.approx(d_args['etw_refet'])
 
+
 def test_refet_daily_eto_fs1():
     refet = Daily(
-        tmax=ee.Image.constant(d_args['tmax']),
-        tmin=ee.Image.constant(d_args['tmin']),
-        ea=ee.Image.constant(d_args['ea']),
-        rs=ee.Image.constant(d_args['rs']),
+        tmax=ee.Image.constant(d_args['tmax']), tmin=ee.Image.constant(d_args['tmin']),
+        ea=ee.Image.constant(d_args['ea']), rs=ee.Image.constant(d_args['rs']),
         uz=ee.Image.constant(d_args['uz']), zw=ee.Number(s_args['zw']),
         elev=ee.Number(s_args['elev']), lat=ee.Number(s_args['lat']),
-        doy=ee.Number(d_args['doy']), method='refet')
-    output = refet.eto_fs1 \
-        .reduceRegion(ee.Reducer.first(), geometry=constant_geom, scale=1) \
+        doy=ee.Number(d_args['doy']), method='refet',
+    )
+
+    output = refet.eto_fs1\
+        .reduceRegion(ee.Reducer.first(), geometry=constant_geom, scale=1)\
         .getInfo()
+
     assert float(output['eto_fs1']) == pytest.approx(d_args['eto_fs1'])
 
+
 def test_refet_daily_eto_fs2():
     refet = Daily(
-        tmax=ee.Image.constant(d_args['tmax']),
-        tmin=ee.Image.constant(d_args['tmin']),
-        ea=ee.Image.constant(d_args['ea']),
-        rs=ee.Image.constant(d_args['rs']),
+        tmax=ee.Image.constant(d_args['tmax']), tmin=ee.Image.constant(d_args['tmin']),
+        ea=ee.Image.constant(d_args['ea']), rs=ee.Image.constant(d_args['rs']),
         uz=ee.Image.constant(d_args['uz']), zw=ee.Number(s_args['zw']),
         elev=ee.Number(s_args['elev']), lat=ee.Number(s_args['lat']),
-        doy=ee.Number(d_args['doy']), method='refet')
-    output = refet.eto_fs2 \
-        .reduceRegion(ee.Reducer.first(), geometry=constant_geom, scale=1) \
+        doy=ee.Number(d_args['doy']), method='refet',
+    )
+
+    output = refet.eto_fs2\
+        .reduceRegion(ee.Reducer.first(), geometry=constant_geom, scale=1)\
         .getInfo()
+
     assert float(output['eto_fs2']) == pytest.approx(d_args['eto_fs2'])
 
 
+def test_refet_daily_pet_hargreaves():
+    refet = Daily(
+        tmax=ee.Image.constant(d_args['tmax']), tmin=ee.Image.constant(d_args['tmin']),
+        ea=ee.Image.constant(0), rs=ee.Image.constant(0),
+        uz=ee.Image.constant(0), zw=ee.Number(s_args['zw']),
+        elev=ee.Number(0), lat=ee.Number(s_args['lat']),
+        doy=ee.Number(d_args['doy']), method='asce',
+    )
+
+    output = refet.pet_hargreaves\
+        .reduceRegion(ee.Reducer.first(), geometry=constant_geom, scale=1)\
+        .getInfo()
+
+    assert float(output['pet_hargreaves']) == pytest.approx(d_args['pet_hargreaves'])
+
+
 def test_refet_daily_rso_type_simple():
     refet = Daily(
-        tmax=ee.Image.constant(d_args['tmax']),
-        tmin=ee.Image.constant(d_args['tmin']),
-        ea=ee.Image.constant(d_args['ea']),
-        rs=ee.Image.constant(d_args['rs']),
+        tmax=ee.Image.constant(d_args['tmax']), tmin=ee.Image.constant(d_args['tmin']),
+        ea=ee.Image.constant(d_args['ea']), rs=ee.Image.constant(d_args['rs']),
         uz=ee.Image.constant(d_args['uz']), zw=ee.Number(s_args['zw']),
         elev=ee.Number(s_args['elev']), lat=ee.Number(s_args['lat']),
-        doy=ee.Number(d_args['doy']), method='refet', rso_type='simple')
+        doy=ee.Number(d_args['doy']), method='refet', rso_type='simple',
+    )
+
     output = refet.etr\
         .reduceRegion(ee.Reducer.first(), geometry=constant_geom, scale=1)\
         .getInfo()
+
     assert float(output['etr']) == pytest.approx(d_args['etr_rso_simple'])
 
 
 def test_refet_daily_rso_type_array():
     refet = Daily(
-        tmax=ee.Image.constant(d_args['tmax']),
-        tmin=ee.Image.constant(d_args['tmin']),
-        ea=ee.Image.constant(d_args['ea']),
-        rs=ee.Image.constant(d_args['rs']),
+        tmax=ee.Image.constant(d_args['tmax']), tmin=ee.Image.constant(d_args['tmin']),
+        ea=ee.Image.constant(d_args['ea']), rs=ee.Image.constant(d_args['rs']),
         uz=ee.Image.constant(d_args['uz']), zw=ee.Number(s_args['zw']),
         elev=ee.Number(s_args['elev']), lat=ee.Number(s_args['lat']),
         doy=ee.Number(d_args['doy']), method='refet',
-        rso_type='array', rso=ee.Number(d_args['rso']))
+        rso_type='array', rso=ee.Number(d_args['rso']),
+    )
+
     output = refet.etr\
         .reduceRegion(ee.Reducer.first(), geometry=constant_geom, scale=1)\
         .getInfo()
+
     assert float(output['etr']) == pytest.approx(d_args['etr_refet'])
 
 
@@ -172,111 +205,126 @@ def test_refet_daily_rso_type_exception():
             rs=ee.Image.constant(d_args['rs']),
             uz=ee.Image.constant(d_args['uz']), zw=ee.Number(s_args['zw']),
             elev=ee.Number(s_args['elev']), lat=ee.Number(s_args['lat']),
-            doy=ee.Number(d_args['doy']), rso_type='nonsense', method='refet')
+            doy=ee.Number(d_args['doy']), rso_type='nonsense', method='refet',
+        )
 
 
 def test_refet_daily_etr_asce():
     refet = Daily(
-        tmax=ee.Image.constant(d_args['tmax']),
-        tmin=ee.Image.constant(d_args['tmin']),
-        ea=ee.Image.constant(d_args['ea']),
-        rs=ee.Image.constant(d_args['rs']),
+        tmax=ee.Image.constant(d_args['tmax']), tmin=ee.Image.constant(d_args['tmin']),
+        ea=ee.Image.constant(d_args['ea']), rs=ee.Image.constant(d_args['rs']),
         uz=ee.Image.constant(d_args['uz']), zw=ee.Number(s_args['zw']),
         elev=ee.Number(s_args['elev']), lat=ee.Number(s_args['lat']),
-        doy=ee.Number(d_args['doy']), method='asce')
+        doy=ee.Number(d_args['doy']), method='asce',
+    )
+
     output = refet.etr.reduceRegion(
         reducer=ee.Reducer.first(),
         geometry=ee.Geometry.Rectangle([0, 0, 10, 10], 'EPSG:32613', False),
         scale=1).getInfo()
+
     assert float(output['etr']) == pytest.approx(d_args['etr_asce'])
 
 
 @pytest.mark.parametrize(
     'surface, expected',
-    [['etr', d_args['etr_refet']],
-     ['alfalfa', d_args['etr_refet']],
-     ['tall', d_args['etr_refet']],
-     ['eto', d_args['eto_refet']],
-     ['grass', d_args['eto_refet']],
-     ['short', d_args['eto_refet']]])
+    [
+        ['etr', d_args['etr_refet']],
+        ['alfalfa', d_args['etr_refet']],
+        ['tall', d_args['etr_refet']],
+        ['eto', d_args['eto_refet']],
+        ['grass', d_args['eto_refet']],
+        ['short', d_args['eto_refet']],
+    ]
+)
 def test_refet_daily_etsz(surface, expected):
     refet = Daily(
-        tmax=ee.Image.constant(d_args['tmax']),
-        tmin=ee.Image.constant(d_args['tmin']),
-        ea=ee.Image.constant(d_args['ea']),
-        rs=ee.Image.constant(d_args['rs']),
+        tmax=ee.Image.constant(d_args['tmax']), tmin=ee.Image.constant(d_args['tmin']),
+        ea=ee.Image.constant(d_args['ea']), rs=ee.Image.constant(d_args['rs']),
         uz=ee.Image.constant(d_args['uz']), zw=ee.Number(s_args['zw']),
         elev=ee.Number(s_args['elev']), lat=ee.Number(s_args['lat']),
-        doy=ee.Number(d_args['doy']), method='refet')
+        doy=ee.Number(d_args['doy']), method='refet',
+    )
+
     output = refet.etsz(surface).rename(['etsz']).reduceRegion(
         reducer=ee.Reducer.first(),
         geometry=ee.Geometry.Rectangle([0, 0, 10, 10], 'EPSG:32613', False),
         scale=1).getInfo()
+
     assert float(output['etsz']) == pytest.approx(expected)
 
 
 def test_refet_daily_gridmet_etr():
-    """Generate a fake GRIDMET image from the test values"""
-    gridmet_img = ee.Image.constant([
+    """Generate a mock GRIDMET image from the test values"""
+    input_img = ee.Image.constant([
             d_args['tmax'] + 273.15, d_args['tmin'] + 273.15,
             d_args['q_asce'], d_args['rs'] / 0.0864, d_args['uz']])\
         .rename(['tmmx', 'tmmn', 'sph', 'srad', 'vs'])\
         .set('system:time_start', ee.Date('2015-07-01').millis())
+
     refet = Daily.gridmet(
-        ee.Image(gridmet_img), elev=ee.Number(s_args['elev']),
-        lat=ee.Number(s_args['lat']), zw=ee.Number(s_args['zw']),
-        method='asce')
+        ee.Image(input_img), elev=ee.Number(s_args['elev']),
+        lat=ee.Number(s_args['lat']), zw=ee.Number(s_args['zw']), method='asce',
+    )
+
     output = refet.etr\
         .reduceRegion(ee.Reducer.first(), geometry=constant_geom, scale=1)\
         .getInfo()
+
     assert float(output['etr']) == pytest.approx(d_args['etr_asce'])
 
 
 def test_refet_daily_maca_etr():
-    """Generate a fake MACA image from the test values"""
-    maca_img = ee.Image.constant([
+    """Generate a mock MACA image from the test values"""
+    input_img = ee.Image.constant([
             d_args['tmax'] + 273.15, d_args['tmin'] + 273.15,
             d_args['q_asce'], d_args['rs'] / 0.0864,
-            d_args['uz'] / (2 ** 0.5), d_args['uz'] / (2 ** 0.5)])\
+            d_args['uz_x'], d_args['uz_y']])\
         .rename(['tasmax', 'tasmin', 'huss', 'rsds', 'uas', 'vas'])\
         .set('system:time_start', ee.Date('2015-07-01').millis())
+
     refet = Daily.maca(
-        ee.Image(maca_img), elev=ee.Number(s_args['elev']),
-        lat=ee.Number(s_args['lat']), zw=ee.Number(s_args['zw']),
-        method='asce')
+        ee.Image(input_img), elev=ee.Number(s_args['elev']),
+        lat=ee.Number(s_args['lat']), zw=ee.Number(s_args['zw']), method='asce',
+    )
+
     output = refet.etr\
         .reduceRegion(ee.Reducer.first(), geometry=constant_geom, scale=1)\
         .getInfo()
+
     assert float(output['etr']) == pytest.approx(d_args['etr_asce'])
 
 
 def test_refet_daily_nldas_etr():
-    """Generate a fake NLDAS image from the test values
+    """Generate a mock NLDAS image from the test values
 
     Convert the test Rs from MJ m-2 d-1 to W m-2, then allocate half to each image
 
     """
-    band_names = ['temperature', 'specific_humidity',
-                  'shortwave_radiation', 'wind_u', 'wind_v']
+    band_names = [
+        'temperature', 'specific_humidity', 'shortwave_radiation', 'wind_u', 'wind_v'
+    ]
 
-    wind_u = d_args['uz'] / (2 ** 0.5)
-    nldas_coll = ee.ImageCollection.fromImages([
-        ee.Image.constant([d_args['tmin'], d_args['q_asce'],
-                           0.0, wind_u, wind_u]) \
-            .double().rename(band_names) \
+    input_coll = ee.ImageCollection.fromImages([
+        ee.Image.constant([d_args['tmin'], d_args['q_asce'], 0.0,
+                           d_args['uz_x'], d_args['uz_y']])
+            .double().rename(band_names)
             .set({'system:time_start': ee.Date('2015-07-01T00:00:00', 'UTC').millis()}),
-        ee.Image.constant([d_args['tmax'], d_args['q_asce'],
-                           d_args['rs'] / 0.0036, wind_u, wind_u]) \
-            .double().rename(band_names) \
+        ee.Image.constant([d_args['tmax'], d_args['q_asce'], d_args['rs'] / 0.0036,
+                           d_args['uz_x'], d_args['uz_y']])
+            .double().rename(band_names)
             .set({'system:time_start': ee.Date('2015-07-01T12:00:00', 'UTC').millis()})
     ])
 
     refet = Daily.nldas(
-        nldas_coll, elev=ee.Number(s_args['elev']),
-        lat=ee.Number(s_args['lat']), zw=ee.Number(s_args['zw']), method='asce')
+        input_coll, elev=ee.Number(s_args['elev']),
+        lat=ee.Number(s_args['lat']), zw=ee.Number(s_args['zw']), method='asce',
+    )
+
     output = refet.etr\
         .reduceRegion(ee.Reducer.first(), geometry=constant_geom, scale=1)\
         .getInfo()
+
     assert float(output['etr']) == pytest.approx(d_args['etr_asce'])
 
 
@@ -284,9 +332,9 @@ def test_refet_daily_nldas_eto():
     """Compare values to previous calculations"""
     test_point = ee.Geometry.Point(-120.113, 36.336)
 
-    nldas_coll = ee.ImageCollection('NASA/NLDAS/FORA0125_H002')\
+    input_coll = ee.ImageCollection('NASA/NLDAS/FORA0125_H002')\
         .filterDate('2017-07-01T06:00:00', '2017-07-02T06:00:00')
-    output = Daily.nldas(nldas_coll, method='asce').eto \
+    output = Daily.nldas(input_coll, method='asce').eto\
         .reduceRegion(ee.Reducer.first(), geometry=test_point, scale=1)\
         .getInfo()['eto']
 
@@ -299,7 +347,7 @@ def test_refet_daily_nldas_eto():
 
 
 def test_refet_daily_cfsv2_etr():
-    """Generate a fake CFSv2 image from the test values
+    """Generate a mock CFSv2 image from the test values
 
     Convert the test Rs from MJ m-2 d-1 to W m-2
 
@@ -313,61 +361,128 @@ def test_refet_daily_cfsv2_etr():
         'v-component_of_wind_height_above_ground',
     ]
 
-    wind_u = d_args['uz'] / (2 ** 0.5)
-
-    cfsv2_coll = ee.ImageCollection.fromImages([
+    input_coll = ee.ImageCollection.fromImages([
         ee.Image.constant([d_args['tmax'] + 273.15, d_args['tmin'] + 273.15,
                            d_args['q_asce'], d_args['rs'] / 0.0864,
-                           wind_u, wind_u]) \
-            .double().rename(band_names) \
+                           d_args['uz_x'], d_args['uz_y']])
+            .double().rename(band_names)
             .set({'system:time_start': ee.Date('2015-07-01T00:00:00', 'UTC').millis()}),
         ee.Image.constant([d_args['tmax'] + 273.15, d_args['tmin'] + 273.15,
                            d_args['q_asce'], d_args['rs'] / 0.0864,
-                           wind_u, wind_u]) \
-            .double().rename(band_names) \
+                           d_args['uz_x'], d_args['uz_y']])
+            .double().rename(band_names)
             .set({'system:time_start': ee.Date('2015-07-01T06:00:00', 'UTC').millis()}),
         ee.Image.constant([d_args['tmax'] + 273.15, d_args['tmin'] + 273.15,
                            d_args['q_asce'], d_args['rs'] / 0.0864,
-                           wind_u, wind_u]) \
-             .double().rename(band_names) \
-             .set({'system:time_start': ee.Date('2015-07-01T12:00:00', 'UTC').millis()}),
+                           d_args['uz_x'], d_args['uz_y']])
+            .double().rename(band_names)
+            .set({'system:time_start': ee.Date('2015-07-01T12:00:00', 'UTC').millis()}),
         ee.Image.constant([d_args['tmax'] + 273.15, d_args['tmin'] + 273.15,
                            d_args['q_asce'], d_args['rs'] / 0.0864,
-                           wind_u, wind_u]) \
-             .double().rename(band_names) \
-             .set({'system:time_start': ee.Date('2015-07-01T18:00:00', 'UTC').millis()}),
+                           d_args['uz_x'], d_args['uz_y']])
+            .double().rename(band_names)
+            .set({'system:time_start': ee.Date('2015-07-01T18:00:00', 'UTC').millis()}),
     ])
 
     refet = Daily.cfsv2(
-        cfsv2_coll, elev=ee.Number(s_args['elev']),
-        lat=ee.Number(s_args['lat']), zw=ee.Number(s_args['zw']), method='asce')
+        input_coll, elev=ee.Number(s_args['elev']), lat=ee.Number(s_args['lat']),
+        zw=ee.Number(s_args['zw']), method='asce',
+    )
+
     output = refet.etr\
         .reduceRegion(ee.Reducer.first(), geometry=constant_geom, scale=1)\
         .getInfo()
+
     assert float(output['etr']) == pytest.approx(d_args['etr_asce'])
 
 
 def test_refet_daily_rtma_etr():
-    """Generate a fake RTMA image from the test values"""
+    """Generate a mock RTMA image from the test values"""
     band_names = ['TMP', 'SPFH', 'WIND']
 
-    rtma_coll = ee.ImageCollection.fromImages([
-        ee.Image.constant([d_args['tmin'], d_args['q_asce'], d_args['uz']]) \
-            .double().rename(band_names) \
+    input_coll = ee.ImageCollection.fromImages([
+        ee.Image.constant([d_args['tmin'], d_args['q_asce'], d_args['uz']])
+            .double().rename(band_names)
             .set({'system:time_start': ee.Date('2015-07-01T00:00:00', 'UTC').millis()}),
-        ee.Image.constant([d_args['tmax'], d_args['q_asce'], d_args['uz']]) \
-            .double().rename(band_names) \
+        ee.Image.constant([d_args['tmax'], d_args['q_asce'], d_args['uz']])
+            .double().rename(band_names)
             .set({'system:time_start': ee.Date('2015-07-01T12:00:00', 'UTC').millis()})
     ])
 
     refet = Daily.rtma(
-        rtma_coll,
-        rs=ee.Image.constant(d_args['rs']),
+        input_coll, rs=ee.Image.constant(d_args['rs']),
         elev=ee.Number(s_args['elev']), lat=ee.Number(s_args['lat']),
-        zw=ee.Number(s_args['zw']), method='asce')
+        zw=ee.Number(s_args['zw']), method='asce',
+    )
+
     output = refet.etr\
         .reduceRegion(ee.Reducer.first(), geometry=constant_geom, scale=1)\
         .getInfo()
+
+    assert float(output['etr']) == pytest.approx(d_args['etr_asce'])
+
+
+def test_refet_daily_era5_etr():
+    """Generate a mock ERA5 image from the test values"""
+    band_names = [
+        'temperature_2m', 'dewpoint_temperature_2m',
+        'surface_solar_radiation_downwards',
+        'u_component_of_wind_10m', 'v_component_of_wind_10m',
+    ]
+
+    # Each image needs half of the total Rs since hourly images are summed
+    input_coll = ee.ImageCollection.fromImages([
+        ee.Image.constant([d_args['tmin'] + 273.15, d_args['tdew'] + 273.15,
+                           0.0, d_args['uz_x'], d_args['uz_y']])
+            .double().rename(band_names)
+            .set({'system:time_start': ee.Date('2015-07-01T00:00:00', 'UTC').millis()}),
+        ee.Image.constant([d_args['tmax'] + 273.15, d_args['tdew'] + 273.15,
+                           d_args['rs'] * 1000000, d_args['uz_x'], d_args['uz_y']])
+            .double().rename(band_names)
+            .set({'system:time_start': ee.Date('2015-07-01T12:00:00', 'UTC').millis()})
+    ])
+
+    refet = Daily.era5(
+        input_coll, elev=ee.Number(s_args['elev']), lat=ee.Number(s_args['lat']),
+        zw=ee.Number(s_args['zw']), method='asce',
+    )
+
+    output = refet.etr\
+        .reduceRegion(ee.Reducer.first(), geometry=constant_geom, scale=1)\
+        .getInfo()
+
+    assert float(output['etr']) == pytest.approx(d_args['etr_asce'])
+
+
+def test_refet_daily_era5_land_etr():
+    """Generate a mock ERA5-Land image from the test values"""
+    band_names = [
+        'temperature_2m', 'dewpoint_temperature_2m',
+        'surface_solar_radiation_downwards_hourly',
+        'u_component_of_wind_10m', 'v_component_of_wind_10m',
+    ]
+
+    # Each image needs half of the total Rs since hourly images are summed
+    input_coll = ee.ImageCollection.fromImages([
+        ee.Image.constant([d_args['tmin'] + 273.15, d_args['tdew'] + 273.15,
+                           0.0, d_args['uz_x'], d_args['uz_y']])
+            .double().rename(band_names)
+            .set({'system:time_start': ee.Date('2015-07-01T00:00:00', 'UTC').millis()}),
+        ee.Image.constant([d_args['tmax'] + 273.15, d_args['tdew'] + 273.15,
+                           d_args['rs'] * 1000000, d_args['uz_x'], d_args['uz_y']])
+            .double().rename(band_names)
+            .set({'system:time_start': ee.Date('2015-07-01T12:00:00', 'UTC').millis()})
+    ])
+
+    refet = Daily.era5_land(
+        input_coll, elev=ee.Number(s_args['elev']), lat=ee.Number(s_args['lat']),
+        zw=ee.Number(s_args['zw']), method='asce',
+    )
+
+    output = refet.etr\
+        .reduceRegion(ee.Reducer.first(), geometry=constant_geom, scale=1)\
+        .getInfo()
+
     assert float(output['etr']) == pytest.approx(d_args['etr_asce'])
 
 
